Welcome to django-extensions’s documentation! — django-extensions 0.9.1-beta documentation

### Navigation

- index
- next |
- django-extensions 0.9.1-beta documentation »

# Welcome to django-extensions’s documentation!

Django Extensions is a collection of custom extensions for the Django Framework.

These include management commands, additional database field, admin extensions and much more.

# Getting Started

The easiest way to figure out what Django Extensions are all about is to watch the excellent screencast by Eric Holscher. In a couple minutes Eric walks you through a half a dozen command extensions.

# Getting it

You can get Django Extensions by using pip or easy_install:

    $ pip install django-extensions
    or
    $ easy_install django-extensions

If you want to install it from source, grab the git repository and run setup.py:

    $ git clone git://github.com/django-extensions/django-extensions.git
    $ cd django-extensions
    $ python setup.py install

For more detailed instructions check out our Installation instructions. Enjoy.

# Contents

- Current Admin Extensions
- Ideas for New Command Extensions
- Current Command Extensions
- shell_plus
  - Configuration
- create_app
  - Example Usage
  - Example generated from sample.dia
- dumpscript
  - Why?
  - Features
  - What it can’t do (yet!)
  - How?
- Caveats
- export_emails
  - Example Usage
  - Current Supported Formats
    - address
    - google
    - outlook
    - linkedin
    - vcard
- Field Extensions
  - Current Database Model Field Extensions
- Graph models
  - Example Usage
- Installation instructions
  - Download and installation
    - Pip and easy_install
    - Download
    - Installation
  - Version Control
- Jobs scheduling
  - JobsScheduling
    - This page is very much; Work in Progress
- Model extensions
  - Current Database Model Extensions
- Namespace proposal
  - Introduction
  - Proposal of a Namespace
- print_settings
  - Introduction
  - More Info
- RunProfileServer
  - Introduction
  - gather_profile_stats.py
  - KCacheGrind
  - Links
- RunServerPlus
  - Introduction
  - Getting Started
  - Using
    - View Source
    - Interactive Debugging Console
- sync_media_s3
  - Example Usage
  - Required libraries and settings
- sqldiff
  - Example Usage
- sqlcreate
  - Introduction
  - Usage
  - Example
    - PostgreSQL
    - MySQL
  - Known Issues

# Indices and tables

- Search Page

### Navigation

- index
- next |
- django-extensions 0.9.1-beta documentation »